==> activity-custom-center-api-0.1.4-sources.jar: cn/com/duiba/activity/custom/center/api/dto/bonus/DeveloperBonusLogDto.java <==
package cn.com.duiba.activity.custom.center.api.dto.bonus;

import org.apache.commons.lang3.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.Date;

/**
 * @author chengsiyi
 * @date 2018/11/30 15:50
 */
public class DeveloperBonusLogDto implements Serializable {

    private static final long serialVersionUID = 8812810884224307795L;

    private Long id;

    private Long consumerId;

    private Long appId;

    private String partnerUserId;

    private Long bonus;

    private Date gmtCreate;

    private Date gmtModified;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getPartnerUserId() {
        return partnerUserId;
    }

    public void setPartnerUserId(String partnerUserId) {
        this.partnerUserId = partnerUserId;
    }

    public Long getBonus() {
        return bonus;
    }

    public void setBonus(Long bonus) {
        this.bonus = bonus;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}

==> activity-custom-center-api-0.3.191-sources.jar: cn/com/duiba/activity/custom/center/api/dto/bonus/DeveloperBonusLogDto.java <==
package cn.com.duiba.activity.custom.center.api.dto.bonus;

import org.apache.commons.lang3.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.Date;

/**
 * @author chengsiyi
 * @date 2018/11/30 15:50
 */
public class DeveloperBonusLogDto implements Serializable {

    private static final long serialVersionUID = 8812810884224307795L;

    private Long id;

    private Long consumerId;

    private Long appId;

    private String partnerUserId;

    private Long bonus;

    private String remark;

    /**
     * 南昌招行  操作类型：1. 首次红包奖励 2 ： 团长 3人瓜分奖励 3 ：团长10分瓜分奖励
     * 4 团员 3人瓜分奖励 5: 团员10分瓜分奖励
     */
    private Integer opType;


    /**
     * 南昌招行   1. 待领取 2. 已领取
     */
    private Integer opStatus;



    private Date gmtCreate;

    private Date gmtModified;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getPartnerUserId() {
        return partnerUserId;
    }

    public void setPartnerUserId(String partnerUserId) {
        this.partnerUserId = partnerUserId;
    }

    public Long getBonus() {
        return bonus;
    }

    public void setBonus(Long bonus) {
        this.bonus = bonus;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Integer getOpType() {
        return opType;
    }

    public void setOpType(Integer opType) {
        this.opType = opType;
    }

    public Integer getOpStatus() {
        return opStatus;
    }

    public void setOpStatus(Integer opStatus) {
        this.opStatus = opStatus;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}
